@@ -5,23 +5,20 @@ from typing import Callable, List, Optional, Union
 
 from kafka import KafkaConsumer
 
-KAFKA_HOST = os.environ.get("KAFKA_HOST", "localhost")
-KAFKA_PORT = os.environ.get("KAFKA_PORT", "9092")
-KAFKA_API_VERSION = os.environ.get("KAFKA_API_VERSION", "2.5.0")
-
 
 def create_kafka_consumer(
-    group_id: Optional[str], topics: Union[str, List[str]]
+    kafka_uri: str, group_id: Optional[str], topics: Union[str, List[str]]
 ) -> KafkaConsumer:
     logging.info("Creating Kafka Consumer...")
+    kafka_api_version = os.environ.get("KAFKA_API_VERSION", "2.5.0")
     consumer = KafkaConsumer(
-        bootstrap_servers=f"{KAFKA_HOST}:{KAFKA_PORT}",
+        bootstrap_servers=kafka_uri,
         group_id=group_id,
         reconnect_backoff_max_ms=100000,  # TODO: what value to set here?
         # API Version is needed in order to prevent api version guessing leading to an error
         # on startup if Kafka Broker isn't ready yet
         api_version=tuple(
-            [int(value) for value in KAFKA_API_VERSION.split(".")]
+            [int(value) for value in kafka_api_version.split(".")]
         ),
     )
     consumer.subscribe(topics)
@@ -30,13 +27,15 @@ def create_kafka_consumer(
 
 
 def consume_kafka(
+    kafka_uri: str,
     group_id: Optional[str],
     topics: Union[str, List[str]],
     message_processing_func: Callable[[dict], None],
 ) -> None:
-    consumer = create_kafka_consumer(group_id, topics)
+    consumer = create_kafka_consumer(kafka_uri, group_id, topics)
     logging.info("Ready to consume messages")
     for message in consumer:
         val_utf8 = message.value.decode("utf-8").replace("NaN", "null")
+        key = message.key.decode("utf-8")
         data = json.loads(val_utf8)
-        message_processing_func(data)
+        message_processing_func(key, data)
