@@ -3,31 +3,33 @@ import os
 
 from kafka import KafkaProducer
 
-KAFKA_HOST = os.environ.get("KAFKA_HOST", "localhost")
-KAFKA_PORT = os.environ.get("KAFKA_PORT", "9092")
-
 
 class KafkaProducerSingleton:
     __instance = None
 
     @staticmethod
-    def get_instance() -> KafkaProducer:
+    def get_instance(kafka_uri: str) -> KafkaProducer:
         if KafkaProducerSingleton.__instance is None:
+            kafka_api_version = os.environ.get("KAFKA_API_VERSION", "2.5.0")
             KafkaProducerSingleton.__instance = KafkaProducer(
-                bootstrap_servers=f"{KAFKA_HOST}:{KAFKA_PORT}",
+                bootstrap_servers=kafka_uri,
                 value_serializer=lambda v: json.dumps(v).encode("utf-8"),
+                api_version=tuple(
+                    [int(value) for value in kafka_api_version.split(".")]
+                ),
             )
         return KafkaProducerSingleton.__instance
 
 
 def produce(
+    kafka_uri: str,
     topic: str,
     service: str,
     key_id: str,
     document: dict = None,
     meta: dict = None,
 ) -> None:
-    producer = KafkaProducerSingleton.get_instance()
+    producer = KafkaProducerSingleton.get_instance(kafka_uri)
     key = key_id.encode("utf-8")
     value = {"service": service, "value": document, "meta": meta}
     producer.send(topic=topic, value=value, key=key)
